#[non_exhaustive]pub struct CreateBillingAccountRequest {
pub billing_account: Option<BillingAccount>,
pub parent: String,
/* private fields */
}Expand description
Request message for CreateBillingAccount.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.billing_account: Option<BillingAccount>Required. The billing account resource to create. Currently CreateBillingAccount only supports subaccount creation, so any created billing accounts must be under a provided parent billing account.
parent: StringOptional. The parent to create a billing account from. Format:
billingAccounts/{billing_account_id}, for example,billingAccounts/012345-567890-ABCDEF
Implementations
Sourceimpl CreateBillingAccountRequest
impl CreateBillingAccountRequest
pub fn new() -> Self
Sourcepub fn set_billing_account<T>(self, v: T) -> Selfwhere
T: Into<BillingAccount>,
pub fn set_billing_account<T>(self, v: T) -> Selfwhere
T: Into<BillingAccount>,
Sets the value of billing_account.
Example
ⓘ
use google_cloud_billing_v1::model::BillingAccount;
let x = CreateBillingAccountRequest::new().set_billing_account(BillingAccount::default()/* use setters */);Sourcepub fn set_or_clear_billing_account<T>(self, v: Option<T>) -> Selfwhere
T: Into<BillingAccount>,
pub fn set_or_clear_billing_account<T>(self, v: Option<T>) -> Selfwhere
T: Into<BillingAccount>,
Sets or clears the value of billing_account.
Example
ⓘ
use google_cloud_billing_v1::model::BillingAccount;
let x = CreateBillingAccountRequest::new().set_or_clear_billing_account(Some(BillingAccount::default()/* use setters */));
let x = CreateBillingAccountRequest::new().set_or_clear_billing_account(None::<BillingAccount>);Trait Implementations
Sourceimpl Clone for CreateBillingAccountRequest
impl Clone for CreateBillingAccountRequest
Sourcefn clone(&self) -> CreateBillingAccountRequest
fn clone(&self) -> CreateBillingAccountRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateBillingAccountRequest
impl Debug for CreateBillingAccountRequest
Sourceimpl Default for CreateBillingAccountRequest
impl Default for CreateBillingAccountRequest
Sourcefn default() -> CreateBillingAccountRequest
fn default() -> CreateBillingAccountRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for CreateBillingAccountRequest