#[non_exhaustive]pub struct ListProjectBillingInfoRequest {
pub name: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for ListProjectBillingInfo.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the billing account associated with the
projects that you want to list. For example,
billingAccounts/012345-567890-ABCDEF.
page_size: i32Requested page size. The maximum page size is 100; this is also the default.
page_token: StringA token identifying a page of results to be returned. This should be a
next_page_token value returned from a previous ListProjectBillingInfo
call. If unspecified, the first page of results is returned.
Implementations
Sourceimpl ListProjectBillingInfoRequest
impl ListProjectBillingInfoRequest
pub fn new() -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListProjectBillingInfoRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListProjectBillingInfoRequest
impl Clone for ListProjectBillingInfoRequest
Sourcefn clone(&self) -> ListProjectBillingInfoRequest
fn clone(&self) -> ListProjectBillingInfoRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListProjectBillingInfoRequest
impl Default for ListProjectBillingInfoRequest
Sourcefn default() -> ListProjectBillingInfoRequest
fn default() -> ListProjectBillingInfoRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListProjectBillingInfoRequest
impl PartialEq for ListProjectBillingInfoRequest
Sourcefn eq(&self, other: &ListProjectBillingInfoRequest) -> bool
fn eq(&self, other: &ListProjectBillingInfoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListProjectBillingInfoRequest