#[non_exhaustive]pub struct ListProjectBillingInfoResponse {
pub project_billing_info: Vec<ProjectBillingInfo>,
pub next_page_token: String,
/* private fields */
}Expand description
Request message for ListProjectBillingInfoResponse.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_billing_info: Vec<ProjectBillingInfo>A list of ProjectBillingInfo resources representing the projects
associated with the billing account.
next_page_token: StringA token to retrieve the next page of results. To retrieve the next page,
call ListProjectBillingInfo again with the page_token field set to this
value. This field is empty if there are no more results to retrieve.
Implementations
Sourceimpl ListProjectBillingInfoResponse
impl ListProjectBillingInfoResponse
pub fn new() -> Self
Sourcepub fn set_project_billing_info<T, V>(self, v: T) -> Self
pub fn set_project_billing_info<T, V>(self, v: T) -> Self
Sets the value of project_billing_info.
Example
ⓘ
use google_cloud_billing_v1::model::ProjectBillingInfo;
let x = ListProjectBillingInfoResponse::new()
.set_project_billing_info([
ProjectBillingInfo::default()/* use setters */,
ProjectBillingInfo::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListProjectBillingInfoResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListProjectBillingInfoResponse
impl Clone for ListProjectBillingInfoResponse
Sourcefn clone(&self) -> ListProjectBillingInfoResponse
fn clone(&self) -> ListProjectBillingInfoResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListProjectBillingInfoResponse
impl Default for ListProjectBillingInfoResponse
Sourcefn default() -> ListProjectBillingInfoResponse
fn default() -> ListProjectBillingInfoResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListProjectBillingInfoResponse
impl PartialEq for ListProjectBillingInfoResponse
Sourcefn eq(&self, other: &ListProjectBillingInfoResponse) -> bool
fn eq(&self, other: &ListProjectBillingInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListProjectBillingInfoResponse