#[non_exhaustive]pub struct MoveBillingAccountRequest {
pub name: String,
pub destination_parent: String,
/* private fields */
}Expand description
Request message for MoveBillingAccount RPC.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the billing account to move.
Must be of the form billingAccounts/{billing_account_id}.
The specified billing account cannot be a subaccount, since a subaccount
always belongs to the same organization as its parent account.
destination_parent: StringRequired. The resource name of the Organization to move
the billing account under.
Must be of the form organizations/{organization_id}.
Implementations
Sourceimpl MoveBillingAccountRequest
impl MoveBillingAccountRequest