#[non_exhaustive]pub struct ProjectBillingInfo {
pub name: String,
pub project_id: String,
pub billing_account_name: String,
pub billing_enabled: bool,
/* private fields */
}Expand description
Encapsulation of billing information for a Google Cloud Console project. A project has at most one associated billing account at a time (but a billing account can be assigned to multiple projects).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name for the ProjectBillingInfo; has the form
projects/{project_id}/billingInfo. For example, the resource name for the
billing information for project tokyo-rain-123 would be
projects/tokyo-rain-123/billingInfo.
project_id: StringOutput only. The ID of the project that this ProjectBillingInfo
represents, such as tokyo-rain-123. This is a convenience field so that
you don’t need to parse the name field to obtain a project ID.
billing_account_name: StringThe resource name of the billing account associated with the project, if
any. For example, billingAccounts/012345-567890-ABCDEF.
billing_enabled: boolOutput only. True if the project is associated with an open billing account, to which usage on the project is charged. False if the project is associated with a closed billing account, or no billing account at all, and therefore cannot use paid services.
Implementations
Sourceimpl ProjectBillingInfo
impl ProjectBillingInfo
pub fn new() -> Self
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sets the value of project_id.
Example
let x = ProjectBillingInfo::new().set_project_id("example");Sourcepub fn set_billing_account_name<T: Into<String>>(self, v: T) -> Self
pub fn set_billing_account_name<T: Into<String>>(self, v: T) -> Self
Sets the value of billing_account_name.
Example
let x = ProjectBillingInfo::new().set_billing_account_name("example");Sourcepub fn set_billing_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_billing_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of billing_enabled.
Example
let x = ProjectBillingInfo::new().set_billing_enabled(true);Trait Implementations
Sourceimpl Clone for ProjectBillingInfo
impl Clone for ProjectBillingInfo
Sourcefn clone(&self) -> ProjectBillingInfo
fn clone(&self) -> ProjectBillingInfo
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more