#[non_exhaustive]pub struct UpdateProjectBillingInfoRequest {
pub name: String,
pub project_billing_info: Option<ProjectBillingInfo>,
/* private fields */
}Expand description
Request message for UpdateProjectBillingInfo.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the project associated with the billing
information that you want to update. For example,
projects/tokyo-rain-123.
project_billing_info: Option<ProjectBillingInfo>The new billing information for the project. Output-only fields are
ignored; thus, you can leave empty all fields except
billing_account_name.
Implementations
Sourceimpl UpdateProjectBillingInfoRequest
impl UpdateProjectBillingInfoRequest
pub fn new() -> Self
Sourcepub fn set_project_billing_info<T>(self, v: T) -> Selfwhere
T: Into<ProjectBillingInfo>,
pub fn set_project_billing_info<T>(self, v: T) -> Selfwhere
T: Into<ProjectBillingInfo>,
Sets the value of project_billing_info.
Example
ⓘ
use google_cloud_billing_v1::model::ProjectBillingInfo;
let x = UpdateProjectBillingInfoRequest::new().set_project_billing_info(ProjectBillingInfo::default()/* use setters */);Sourcepub fn set_or_clear_project_billing_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ProjectBillingInfo>,
pub fn set_or_clear_project_billing_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ProjectBillingInfo>,
Sets or clears the value of project_billing_info.
Example
ⓘ
use google_cloud_billing_v1::model::ProjectBillingInfo;
let x = UpdateProjectBillingInfoRequest::new().set_or_clear_project_billing_info(Some(ProjectBillingInfo::default()/* use setters */));
let x = UpdateProjectBillingInfoRequest::new().set_or_clear_project_billing_info(None::<ProjectBillingInfo>);Trait Implementations
Sourceimpl Clone for UpdateProjectBillingInfoRequest
impl Clone for UpdateProjectBillingInfoRequest
Sourcefn clone(&self) -> UpdateProjectBillingInfoRequest
fn clone(&self) -> UpdateProjectBillingInfoRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateProjectBillingInfoRequest
impl Default for UpdateProjectBillingInfoRequest
Sourcefn default() -> UpdateProjectBillingInfoRequest
fn default() -> UpdateProjectBillingInfoRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateProjectBillingInfoRequest
impl PartialEq for UpdateProjectBillingInfoRequest
Sourcefn eq(&self, other: &UpdateProjectBillingInfoRequest) -> bool
fn eq(&self, other: &UpdateProjectBillingInfoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateProjectBillingInfoRequest